@@ -61,6 +61,12 @@ class Component:
             'stopping' if self.is_stopping else 'stopped'))
         return f"<Component {self.__class__.__name__}[{hex(id(self))}] {state}>"
 
+    async def __aenter__(self):
+        await self.run()
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        await self.terminate()
+
     @property
     def parent(self):
         """
